<?php
/**
 * AbleCloud-微信公众号PHP SDK使用示例。
 */

function verifySignature($token, $timestamp, $nonce, $signature) {
	$tmpArr = array($token, $timestamp, $nonce);
    sort($tmpArr, SORT_STRING);
    $tmpStr = implode( $tmpArr );
    $tmpStr = sha1( $tmpStr );
    return $tmpStr == $signature;
}

require_once(dirname(__FILE__) . '/wxConfig.php');

// 获取微信Access Token的工具。
// 该工具是将Access Token和Ticket缓存在本地文件中。实际环境下应采用开发者已有的缓存方法，如数据库、内存缓存等。
require_once(dirname(__FILE__) . '/jssdk.php');
// 引用AbleCloud-微信公众号服务接口ACBridgeWeChat。
require_once(dirname(dirname(__FILE__)) . '/lib/bridge/ACBridgeWeChat.php');

// 处理事件/消息
if ($_SERVER['REQUEST_METHOD'] === 'GET') {
	// GET: 微信验证服务器的请求
	// 验证签名
    $signature = $_GET["signature"];
    $timestamp = $_GET["timestamp"];
    $nonce     = $_GET["nonce"];
    if (!verifySignature(__TOKEN__, $timestamp, $nonce, $signature)) {
    	echo("invalid signature.");
        exit();
    }
	$echostr   = $_GET["echostr"];
	echo($echostr);
	exit();
} else if ($_SERVER['REQUEST_METHOD'] === 'POST') {
	// 验证签名
	$signature = $_GET["signature"];
	$timestamp = $_GET["timestamp"];
	$nonce     = $_GET["nonce"];
	if (!verifySignature(__TOKEN__, $timestamp, $nonce, $signature)) {
		echo("invalid signature.");
		exit();
	}

	// POST: 微信推送的公众号事件/消息。
	$reqBody = file_get_contents('php://input');
	$message = simplexml_load_string($reqBody);
	if ($message === FALSE) {
		echo('Failed to parse request XML message.');
		exit();
	}
	$toUser   = $message->ToUserName;
	$fromUser = $message->FromUserName;
	$msgType  = $message->MsgType;
	switch ($msgType) {
		case 'text':
			// 处理用户发送文本内容的事件。
			$text = $message->Content;
			$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDATA[text]]></MsgType><Content><![CDATA[Received message: ' . $text . ' (' . date('Y-m-d H:i:s', time()) . ')]]></Content></xml>';
			echo($resp);
			exit();
		case 'event':
			// 初始化AbleCloud-微信公众号服务接口ACBridgeWeChat
			$jssdk = new JSSDK(__WX_MP_APP_ID__, __WX_MP_APP_SECRET__);
			$wxBridge = new ACBridgeWeChat($jssdk->getAccessToken(), $jssdk->getJsApiTicket());
			switch($message->Event) {
				case 'subscribe':
					// 调用SDK的消息响应函数与AbleCloud同步
					$unionId = $jssdk->getUserUnionId($fromUser);	// 关注公众号的用户在微信平台对应的UnionID
					$user = $wxBridge->onEventSubscribe($reqBody, $unionId);
					// 依据同步操作结果完成自定义的处理逻辑。 
					if ($user != NULL) {
						error_log('event:subscribe OK.');
						$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDATA[text]]></MsgType><Content><![CDATA[欢迎！(' . date('Y-m-d H:i:s', time()) . ')]]></Content></xml>';
					} else {
						$err = $wxBridge->getLastError();
						error_log('event:subscribe ERROR[' . $err['errCode'] . ']: ' . $err['errMessage']);
						$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDAT    A[text]]></MsgType><Content><![CDATA[注册用户失败：' . $err['errMessage'] . ' (' . date('Y-m-d H:i:s', time()) . ')]]></Content></xml>';
					}
					echo($resp);
					exit();
				case 'unsubscribe':
					// 调用SDK的消息响应函数与AbleCloud同步，依据同步操作结果完成自定义的处理逻辑。
					if ($wxBridge->onEventUnsubscribe($reqBody))
						error_log('event:unsubscribe OK.');
					else {
						$err = $wxBridge->getLastError();
						error_log('event:unsubscribe ERROR[' . $err['errCode'] . ']: ' . $err['errMessage']);
					}
					exit();
			}
			break;
		case 'device_event':
			// 初始化AbleCloud-微信公众号服务接口ACBridgeWeChat
			$jssdk = new JSSDK(__WX_MP_APP_ID__, __WX_MP_APP_SECRET__);
			$wxBridge = new ACBridgeWeChat($jssdk->getAccessToken(), $jssdk->getJsApiTicket());
			switch($message->Event) {
				case 'bind':
					// 调用SDK的消息响应函数与AbleCloud同步。
					// 第三个参数'sub_domain_name'应是被绑定的设备在AbleCloud平台上所属子域的名字。开发者也可以在$reqBody设备的二维码中附加设备所属的子域信息，则$reqBody中也会包含设备的子域信息。
					$device = $wxBridge->onDeviceEventBind($reqBody, 'wxDevice', 'sub_domain_name');
					// 依据同步操作结果完成自定义的处理逻辑。 
					if ($device != NULL) {
						error_log('device_event:bind OK.');
						$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDATA[text]]></MsgType><Content><![CDATA[绑定设备成功！(' . date('Y-m-d H:i:s', time()) . ')]]></Content></xml>';
					} else {
						$err = $wxBridge->getLastError();
						error_log('device_event:bind error[' . $err['errCode'] . ']: ' . $err['errMessage']);
						$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDATA[text]]></MsgType><Content><![CDATA[绑定设备失败: ' . $err['errMessage'] . ' (' . date('y-m-d h:i:s', time()) . ')]]></Content></xml>';
					}
					echo($resp);
					exit();
				case 'unbind':
					// 调用SDK的消息响应函数与AbleCloud同步。
					// 'sub_domain_name'应该要解邦的设备在AbleCloud平台上所属子域的名字。
					$retVal = $wxBridge->onDeviceEventUnbind($reqBody, 'sub_domain_name');
					// 依据同步操作结果完成自定义的处理逻辑。 
					if ($retVal) {
						error_log('device_event:unbind OK.');
						$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDATA[text]]></MsgType><Content><![CDATA[解邦设备成功！(' . date('Y-m-d H:i:s', time()) . ')]]></Content></xml>';
					} else {
						$err = $wxBridge->getLastError();
						error_log('device_event:unbind error[' . $err['errCode'] . ']: ' . $err['errMessage']);
						$resp = '<xml><ToUserName><![CDATA[' . $fromUser . ']]></ToUserName><FromUserName><![CDATA[' . $toUser . ']]></FromUserName><CreateTime>' . time() . '</CreateTime><MsgType><![CDATA[text]]></MsgType><Content><![CDATA[解邦设备失败: ' . $err['errMessage'] . ' (' . date('y-m-d h:i:s', time()) . ')]]></Content></xml>';
					}
					echo($resp);
					exit();
				case 'subscribe_status':
					// 调用SDK的消息响应函数处理微信订阅WiFi设备状态的事件。
					// 第二个参数用于指定是否同时执行设备-用户绑定关系在AbleCloud与微信平台之间的数据同步。
					$respMsg = $wxBridge->onDeviceEventSubscribeStatus($reqBody, FALSE);	// 从AbleCloud取设备状态信息
					if (strlen($respMsg) > 0) {
						error_log('device_event:subscribe_status OK.');
						echo($respMsg);		// 返回设备的状态信息
					} else {
						$err = $wxBridge->getLastError();
						error_log('device_event:subscribe_status error[' . $err['errCode'] . ']: ' . $err['errMessage']);
					}
					exit();
				case 'unsubscribe_status':
					// 调用SDK的消息响应函数处理微信取消订阅WiFi设备状态的事件。
					// 第二个参数用于指定是否同时执行设备-用户绑定关系在AbleCloud与微信平台之间的数据同步。
					$respMsg = $wxBridge->onDeviceEventUnsubscribeStatus($reqBody, FALSE);	// 从AbleCloud取设备状态信息
					if (strlen($respMsg) > 0) {
						error_log('device_event:unsubscribe_status OK.');
						echo($respMsg);		// 返回设备的状态信息
					} else {
						$err = $wxBridge->getLastError();
						error_log('device_event:unsubscribe_status error[' . $err['errCode'] . ']: ' . $err['errMessage']);
					}
					exit();
			}
			break;
		default:
			// 其它事件/消息的处理过程
			break;
	}
}
