<?php

/**
 * 开发者签名工具。
 */
class ACDeveloperSignature {
	/**
	 * 计算开发者的签名。
	 * @param $developer    ACDeveloper ACDeveloper对象，表示要生成其签名的开发者。
	 * @param $context      ACContext   ACContext对象，表示访问AbleCloud远程服务的环境信息。
	 * @param $subDomain    string      字符串。表示要访问的远程服务所属的子域的名字。可能为空字符串。
	 * @param $methodName   string      字符串。表示要访问的远程服务的方法名。
	 * @param $timestamp    int         此次签名所示使用的时间戳。是以秒为单位的UTC时间。
	 * @param $timeout      int         此次签名的有效时长（以秒为单位）。表示该签名在自$timestamp时刻起的$timeout秒之内有效。
	 * @param $nonce        string      此次签名所使用的随机字符串。
	 * @return              string      返回表示签名结果的字符串。
	 */
	public static function signature($developer, $context, $subDomain, $methodName, $timestamp, $timeout, $nonce) {
		$str = $timeout . $timestamp . $nonce . $developer->getId() . $methodName . $context->getMajorDomain() . $subDomain;
    	return hash_hmac('sha256', $str, $developer->getSecretKey());
	}
}