<?php
/**
 * AbleCloud服务的响应消息。
 */
class ACResponse {
	/**
	 * 构造函数。
	 * @param $errorCode	int		响应的状态码。为0时表示成功，否则表示有错误发生。
	 * @param $errorMessage	string	远程服务返回的成功的响应消息或者错误消息。
	 */
	function __construct($errorCode = 0, $errorMessage = '') {
		$this->errorCode = $errorCode;
		$this->errorMessage = $errorMessage;
	}
	
	/**
	 * 检查当前响应消息代表的状态：成功或出错。
	 * @return bool	返回TRUE表示成功，否则表示出错。
	 */
	public function isAck() {
		return $this->errorCode == 0;
	}

	/**
	 * 检查当前响应消息代表的状态：成功或出错。
	 * @return bool	返回TRUE表示出错，否则表示成功。
	 */
	public function isError() {
		return $this->errorCode != 0;
	}

	/**
	 * 取状态码。
	 * @return int	返回状态码。为0时表示成功，其它值表示出错。
	 */
	public function getErrorCode() {
		return $this->errorCode;
	}

	/**
	 * 取响应的错误消息。
	 * @return	string	本方法返回的内容与getResponse()方法返回的内容是一致的。只是从概念上来看，本方法返回的是出错状态下的错误消息。
	 */
	public function getErrorMessage() {
		return $this->errorMessage;
	}

	/**
	 * 取响应的内容。
	 * @return	string	本方法返回的内容与getErrorMessage()方法返回的内容是一致的。只是从概念上来看，本方法返回的是成功状态下的消息内容。
	 */
	public function getResponse() {
		return $this->errorMessage;
	}

	private $errorCode = 0;			// 响应的状态码。为0时表示成功，非0表示有错误发生。
	private $errorMessage = '';		// 响应的具体内容，包括成功时返回的消息以及发生错误时返回的消息。
}
