<?php

/**
 * 设备的元数据信息。
 */
class ACDeviceInfo {
    public $domain = '';         ///< 字符串。设备所属的主域的ID。
    public $subDomain = '';      ///< 字符串。设备所属的子域的ID。
    public $subDomainName = '';  ///< 字符串。设备所属的子域的名字。
    public $physicalDeviceId = '';   ///< 字符串。设备的物理ID。
    public $type = '';           ///< 字符串。
    public $ipAddr = '';         ///< 字符串。设备的IP地址。
    public $mac = '';            ///< 字符串。设备的MAC地址。
    public $devVersion = '';     ///< 字符串。设备的MCU固件版本。
    public $modVersion = '';     ///< 字符串。设备的通信模块版本。
    public $activeTime = '';     ///< 字符串。设备的激活时间。格式为：YYYY-MM-DD HH:mm:ss。
    public $lastOnlineTime = ''; ///< 字符串。设备最近一次上线时间。格式为：YYYY-MM-DD HH:mm:ss。
    public $country = '';        ///< 字符串。设备所处地理位置信息：所在国家。
    public $province = '';       ///< 字符串。设备所处地理位置信息：所在省份。
    public $city = '';           ///< 字符串。设备所处地理位置信息：所在城市。
    public $street = '';         ///< 字符串。设备所处地理位置信息：所在街道。
    public $status = '';         ///< 整数。设备状态：0-不存在；1-未激活；2-激活。

    /**
     * 从关联数组对象构造ACDeviceInfo对象。
     * @param $obj  array               保存了设备信息的对象。
     * @return      ACDeviceInfo | NULL ACDeviceInfo对象或者NULL。
     */
    public static function fromObject($obj) {
        if (!is_array($obj))
            return NULL;
        $dev = new ACDeviceInfo();
        if (array_key_exists('domain', $obj))
            $dev->domain = strval($obj['domain']);
        if (array_key_exists('subDomain', $obj))
            $dev->subDomain = strval($obj['subDomain']);
        if (array_key_exists('subDomainName', $obj))
            $dev->subDomainName = strval($obj['subDomainName']);
        if (array_key_exists('physicalDeviceId', $obj))
            $dev->physicalDeviceId = strval($obj['physicalDeviceId']);
        if (array_key_exists('type', $obj))
            $dev->type = strval($obj['type']);
        if (array_key_exists('ipAddr', $obj))
            $dev->ipAddr = strval($obj['ipAddr']);
        if (array_key_exists('mac', $obj))
            $dev->mac = strval($obj['mac']);
        if (array_key_exists('devVersion', $obj))
            $dev->devVersion = strval($obj['devVersion']);
        if (array_key_exists('modVersion', $obj))
            $dev->modVersion = strval($obj['modVersion']);
        if (array_key_exists('activeTime', $obj))
            $dev->activeTime = strval($obj['activeTime']);
        if (array_key_exists('lastOnlineTime', $obj))
            $dev->lastOnlineTime = strval($obj['lastOnlineTime']);
        if (array_key_exists('country', $obj))
            $dev->country = strval($obj['country']);
        if (array_key_exists('province', $obj))
            $dev->province = strval($obj['province']);
        if (array_key_exists('city', $obj))
            $dev->city = strval($obj['city']);
        if (array_key_exists('street', $obj))
            $dev->street = strval($obj['street']);
        if (array_key_exists('status', $obj))
            $dev->status = strval(intval($obj['status']));
        return $dev;
    }
}
