<?php

require_once(dirname(__FILE__) . '/ACService.php');

/**
 * AbleCloud消息推送服务。
 * 消息推送服务仅适用于推送给APP用户。
 */
class ACNotificationMgr extends ACService {
	/**
	 * 构造函数。
	 * @param $name     string      消息推送服务的名字。
	 * @param $version  int         消息推送服务的版本。
	 * @param $context  ACContext   ACContext对象，表示访问该远程服务所依赖的环境信息。
	 */
	function __construct($name, $version, $context) {
		parent::__construct($name, $version, $context);
	}

	/**
	 * 向设备的用户推送消息。
	 * @param $deviceId 目标设备的逻辑ID。
	 * @param $notification ACNotification对象，表示要被推送的消息。
	 * @param $toUsers 整数。0表示向设备的所有用户推送该消息；1表示向设备的管理员推送该消息。
	 * @return 操作成功时返回TRUE；操作失败时返回FALSE，并且可调用getLastError()方法获取错误消息。
	 */
	public function notifyDeviceUsers($deviceId, $notification, $toUsers) {
		$request = new ACRequest($this->getName(), 'notifyDeviceUsers', $this->getVersion());
		$request->addParameter('userType', $toUsers);
		$request->addParameter('deviceId', $deviceId);
		$request->setPayloadAsJSON($notification->jsonEncode());
		$response = ACHttpClient::doRequest($request, $this->getContext());
		if ($response->isAck()) {
			$this->resetLastError();
			return TRUE;
		} else {
			$this->resetLastError($response->getErrorCode(), $this->getErrorMessage());
			return FALSE;
		}
	}

	/**
	 * 向用户推送消息。
	 * @param $notification 要推送的消息。
	 * @param $toUsers 整数的数组，是消息推送的目标用户ID的集合。
	 * @return 操作成功时返回TRUE；操作失败时返回FALSE，并且可调用getLastError()方法获取错误消息。
	 */
	public function notifyUsers($notification, $toUsers) {
		$request = new ACRequest($this->getName(), 'notifyUsers', $this->getVersion());
		$request->addParameter('userList', $toUsers);
		$request->setPayloadAsJSON($notification->jsonEncode());
		$response = ACHttpClient::doRequest($request, $this->getContext());
		if ($response->isAck()) {
			$this->resetLastError();
			return TRUE;
		} else {
			$this->resetLastError($response->getErrorCode(), $this->getErrorMessage());
			return FALSE;
		}
	}
}