<?php

require_once(dirname(__FILE__) . '/ACService.php');
require_once(dirname(__FILE__) . '/ACOtaVersion.php');

/**
 * AbleCloud设备OTA服务。
 */
class ACOtaMgr extends ACService {
    /**
     * 构造函数。
     * @param $name     string      AbleCloud设备OAT服务的名字。
     * @param $version  int         AbleCloud设备OTAS服务的版本。
     * @param $context  ACContext   ACContext对象，表示访问该远程服务所依赖的环境信息。
     */
    function __construct($name, $version, $context) {
        parent::__construct($name, $version, $context);
    }

    /**
     * 检查设备的固件升级信息。
     * @param $user ACUser对象，表示设备的用户。
     * @param $deviceId 整数，是要被检查的设备的逻辑ID。
     * @param $subDomain 字符串，是待检查的设备所属的子域的名字。
     * @return 返回一个ACOtaVersion对象，表示版本信息。如果操作失败，则返回NULL。此时，可调用getLastError()获取错误信息。
     */
    public function checkUpdate($user, $deviceId, $subDomain) {
        $request = new ACRequest($this->getName(), 'checkUpdate', $this->getVersion(), $subDomain);
        $request->setUser($user);
        $request->setPayloadAsJSON(json_encode(array('deviceId' => intval($deviceId))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            $json = json_decode($response->getResponse(), true);
            if (array_key_exists('upgradeLog', $json))
                return new ACOtaVersion($json['oldVersion'], $json['newVersion'], $json['upgradeLog']);
            else
                return new ACOtaVersion($json['oldVersion'], $json['newVersion']);
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return NULL;
        }
    }

    /**
     * 确认升级设备的固件版本。
     * @param $user ACUser对象，表示执行该操作的用户。
     * @param $deviceId 整数，是要被升级的设备的逻辑ID。
     * @param $subDomain 字符串，是待操作的设备所属的子域的名字。
     * @param $toVersion 字符串，表示升级的目标版本号，如：2-0-3。
     * @return 操作成功时返回TRUE，否则返回FALSE。操作失败时可调用getLastError()获取错误信息。
     */
    public function confirmUpdate($user, $deviceId, $subDomain, $toVersion) {
        $request = new ACRequest($this->getName(), 'confirmUpdate', $this->getVersion(), $subDomain);
        $request->setUser($user);
        $request->setPayloadAsJSON(json_encode(array('deviceId' => intval($deviceId), 'newVersion' => $toVersion)));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }
}