<?php

/**
 * OTA版本信息。
 */
class ACOtaVersion {
    /**
     * 构造函数。
     * @param $currentVersion 字符串，表示当前版本号，如：1-0-1。
     * @param $newVersion 字符串，表示新版本号，如：1-0-2。
     * @param $updateLog 字符串，表示新版本的升级说明。
     */
    function __construct($currentVersion, $newVersion, $updateLog = '') {
        $this->currentVersion = $currentVersion;
        $this->newVersion     = $newVersion;
        $this->updateLog      = $updateLog;
    }

    /**
     * 取当前版本信息。
     * @return 返回一个字符串，表示当前版本。
     */
    public function getCurrentVersion() {
        return $this->currentVersion;
    }

    /**
     * 取新版本信息。
     * @return 返回一个字符串，表示新版本。
     */
    public function getNewVersion() {
        return $this->newVersion;
    }

    /**
     * 取新版本的更新信息。
     * @return 返回一个字符串，表示新版本的升级信息。
     */
    public function getUpdateLog() {
        return $this->updateLog;
    }

    /**
     * 检查是否可升级：检查新版本是否高于当前版本。
     * @return 返回TRUE表示新版本高于当前版本；否则返回FALSE。
     */
    public function canUpdate() {
        $v0 = explode('-', $this->currentVersion, 3);
        $v1 = explode('-', $this->newVersion, 3);
        for ($i = 0; $i < 3; $i++) {
            if (isset($v1[$i])) {
                if (isset($v0[$i])) {
                    if (intval($v1[$i]) > intval($v0[$i]))
                        return TRUE;
                } else {
                    return TRUE;
                }
            } else {
                if (isset($v0[$i]))
                    return FALSE;
            }
        }
        return FALSE;
    }

    private $currentVersion;
    private $newVersion;
    private $updateLog;
}