<?php

require_once(dirname(__FILE__) . '/ACService.php');

/**
 * PHP Session存储服务。
 */
class ACPHPSessionMgr extends ACService implements SessionHandlerInterface {
    /**
     * 构造函数。
     * @param $name		string		AbleCloud天气服务的名字。
     * @param $version	int			AbleCloud天气服务的版本。
     * @param $context	ACContext	ACContext对象，表示访问该远程服务所依赖的环境信息。
     */
    function __construct($name, $version, $context) {
        parent::__construct($name, $version, $context);
    }

    /**
     * SessionHandlerInterface定义的接口。
     * @return bool
     */
    public function close() {
        $request = new ACRequest($this->getName(), 'closePHPSession', $this->getVersion());
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * SessionHandlerInterface定义的接口。
     * @param string $session_id    Session ID。
     * @return bool
     */
    public function destroy($session_id) {
        $request = new ACRequest($this->getName(), 'destroyPHPSession', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('sessionId' => strval($session_id))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * SessionHandlerInterface定义的接口。
     * @param int|string $maxlifetime
     * @return bool
     */
    public function gc($maxlifetime) {
        $request = new ACRequest($this->getName(), 'gcPHPSession', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('maxLiveSeconds' => intval($maxlifetime))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * SessionHandlerInterface定义的接口。
     * @param string $save_path
     * @param string $session_name
     * @return bool
     */
    public function open($save_path, $session_name) {
        $request = new ACRequest($this->getName(), 'openPHPSession', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('savePath' => strval($save_path), 'sessionName' => strval($session_name))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * SessionHandlerInterface定义的接口。
     * @param string $session_id
     * @return string
     */
    public function read($session_id) {
        $request = new ACRequest($this->getName(), 'readPHPSession', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('sessionId' => strval($session_id))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            $json = json_decode($response->getResponse(), true);
            return $json['data'];
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return '';
        }
    }

    /**
     * SessionHandlerInterface定义的接口。
     * @param string $session_id
     * @param string $session_data
     * @return bool
     */
    public function write($session_id, $session_data) {
        $request = new ACRequest($this->getName(), 'writePHPSession', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('sessionId' => strval($session_id), 'data' => strval($session_data))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }
}