<?php

/**
 * 产品信息。
 */
class ACProduct {
    public $domainId = '';          ///< 字符串，主域ID。
    public $domainName = '';        ///< 字符串，主域名字。
    public $subDomainId = '';       ///< 字符串，子域ID。
    public $subDomainName = '';     ///< 字符串，子域名字。
    public $name = '';              ///< 字符串，产品的名字。
    public $type = '';              ///< 字符串，产品类型，如独立设备、网关设备、安卓设备、子设备等。
    public $dataProtocol = '';      ///< 字符串，产品的通信数据格式，如JSON、二进制等。
    public $transportProtocol = ''; ///< 字符串，产品的数据传输协议，如tcp、simple tcp、mqtt、http等。
    public $model = '';             ///< 字符串，产品的型号。
    public $os = '';                ///< 字符串，设备的操作系统名。
    public $connectProtocol = '';   ///< 字符串，设备的连接协议，如wifi、bluetooth、ethernet、cellular等。
    public $description = '';       ///< 字符串，产品的描述信息。
    public $thirdCloud = '';        ///< 字符串，设备对接的物联网云平台的名字。
    public $secType = '';           ///< 字符串，数据加密方式，如RSA、DES等。
    public $category = 0;           ///< 整数，标记产品的品类，如智能家居、可穿戴设备等。
    public $deviceMode = 0;         ///< 整数，设备的管理模式：0（非绑定模式），1（管理员绑定模式），2（普通绑定模式）。
    public $taskMode = 0;           ///< 整数，设备定时模式：0（无定时），1（云端定时），2（设备定时(支持云端定时)）。
    public $taskUpdatePolicy = 0;   ///< 整数，定时任务删除机制：1（普通用户解绑不删除定时任务，管理员解绑删除所有定时任务），2（用户解绑删除定时任务）。
    public $pictureURL = '';        ///< 字符串，产品图片的URL。

    /**
     * 从关联数组对象构造ACProduct对象。
     * @param $obj  array               保存了设备信息的对象。
     * @return      ACProduct | NULL    构造的ACProduct对象或者NULL。
     */
    public static function fromObject($obj) {
        if (!is_array($obj))
            return NULL;
        $product = new ACProduct();
        if (array_key_exists('domain', $obj))
            $product->domainId = $obj['domain'];
        if (array_key_exists('domain_name', $obj))
            $product->domainName = $obj['domain_name'];
        if (array_key_exists('sub_domain', $obj))
            $product->subDomainId = $obj['sub_domain'];
        if (array_key_exists('sub_domain_name', $obj))
            $product->subDomainName = $obj['sub_domain_name'];
        if (array_key_exists('name', $obj))
            $product->name = $obj['name'];
        if (array_key_exists('type', $obj))
            $product->type = $obj['type'];
        if (array_key_exists('protocol', $obj))
            $product->dataProtocol = $obj['protocol'];
        if (array_key_exists('transportProtocol', $obj))
            $product->transportProtocol = $obj['transportProtocol'];
        if (array_key_exists('model', $obj))
            $product->model = $obj['model'];
        if (array_key_exists('os', $obj))
            $product->os = $obj['os'];
        if (array_key_exists('communication', $obj))
            $product->connectProtocol = $obj['communication'];
        if (array_key_exists('description', $obj))
            $product->description = $obj['description'];
        if (array_key_exists('thirdCloud', $obj))
            $product->thirdCloud = $obj['thirdCloud'];
        if (array_key_exists('secType', $obj))
            $product->secType = $obj['secType'];
        if (array_key_exists('category', $obj))
            $product->category = intval($obj['category']);
        if (array_key_exists('deviceMode', $obj))
            $product->deviceMode = intval($obj['deviceMode']);
        if (array_key_exists('taskMode', $obj))
            $product->taskMode = intval($obj['taskMode']);
        if (array_key_exists('taskUpdatePolicy', $obj))
            $product->taskUpdatePolicy = intval($obj['taskUpdatePolicy']);
        if (array_key_exists('productImageUrl', $obj))
            $product->pictureURL = $obj['productImageUrl'];
        return $product;
    }
}