<?php

require_once(dirname(__FILE__) . '/ACService.php');
require_once(dirname(__FILE__) . '/ACProduct.php');

/**
 * AbleCloud产品服务。
 */
class ACProductMgr extends ACService {
    /**
     * 构造函数。
     * @param $name		string		AbleCloud产品服务的名字。
     * @param $version	int			AbleCloud产品服务的主版本号。
     * @param $context	ACContext	表示访问该远程服务所依赖的环境信息。
     */
	function __construct($name, $version, $context) {
        parent::__construct($name, $version, $context);
    }

    /**
     * 获取开发者的产品列表。
     * @return array 操作成功时返回ACProduct对象的数组。操作失败时返回NULL，并可调用方法getLastError()获取错误信息。
     */
    public function getDomainProducts() {
        $request = new ACRequest($this->getName(), 'getDomainProduct', $this->getVersion());
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            $json = json_decode($response->getResponse(), true);
            if (array_key_exists('products', $json)) {
                $list = array();
                foreach ($json['products'] as $p) {
                    $product = ACProduct::fromObject($p);
                    if (!is_null($product)) {
                        array_push($list, $product);
                    }
                }
                return $list;
            } else {
                $this->resetLastError(-1, 'Unknown response from getDomainProduct: ' . $response->getResponse());
                return NULL;
            }
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return NULL;
        }
    }
}