<?php

require_once(dirname(__FILE__) . '/ACQEReadInterface.php');

/**
 * AbleCloud数据分析服务的Count方法。
 */
class ACQECount extends ACQEReadInterface {
    /**
     * 构造函数。
     * @param $name		string		AbleCloud数据分析服务的名字。
     * @param $version	int			AbleCloud数据分析服务的主版本号。
     * @param $context	ACContext	表示访问该远程服务所依赖的环境信息。
     */
    function __construct($name, $version, $context) {
        parent::__construct($name, $version, $context);
    }

    /**
     * 执行 AC-QueryEngine\::count 查询。
     * @return array|bool   返回服务端返回的结果。返回结果为数组时表示访问成功。
     * 返回FALSE时，表示有错误发生。此时可调用getLastError()方法获取错误消息。
     */
    public function execute() {
        $param = $this->getParamInArray();
        if (count($param) < 1) {
            return FALSE;
        }
        $request = new ACRequest($this->getName(), 'count', $this->getVersion());
        $request->setPayloadAsJSON(json_encode($param), 'text/json');
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return json_decode($response->getResponse(), true);
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }
}