<?php

require_once(dirname(__FILE__) . '/ACQEReadInterface.php');

/**
 * AbleCloud数据分析服务的distribution方法。
 */
class ACQEDistribution extends ACQEReadInterface {
    /**
     * 构造函数。
     * @param $name		string		AbleCloud数据分析服务的名字。
     * @param $version	int			AbleCloud数据分析服务的主版本号。
     * @param $context	ACContext	表示访问该远程服务所依赖的环境信息。
     */
    function __construct($name, $version, $context) {
        parent::__construct($name, $version, $context);
        $this->range         = NULL;
        $this->aggregation   = '';
    }

    /**
     * 设置对数据进行哪种聚合操作。是必要参数。
     * @param $name     string      聚合操作的名字：count/count_unique/min/max/avg/sum。
     * @return          ACQECount   返回本对象。
     */
    public function aggregation($name) {
        $this->aggregation = $name;
        return $this;
    }

    /**
     * 设置order_by参数。是必要参数。
     * @param $range    array   整数组成的数组，如array(1, 2, 10, 20)，是不同区间内的聚合结果行的个数。
     * @return          ACQECount   返回本对象。
     */
    public function range($range) {
        $this->range = $range;
        return $this;
    }

    /**
     * 执行 AC-QueryEngine\::distribution 查询。
     * @return array|bool   返回服务端返回的结果。返回结果为数组时表示访问成功。
     * 返回FALSE时，表示有错误发生。此时可调用getLastError()方法获取错误消息。
     */
    public function execute() {
        $param = $this->getParamInArray();
        if (count($param) < 1) {
            return FALSE;
        }
        $request = new ACRequest($this->getName(), 'distribution', $this->getVersion());
        $request->setPayloadAsJSON(json_encode($param), 'text/json');
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return json_decode($response->getResponse(), true);
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * 取数组格式的查询参数。
     * @return array
     */
    protected function getParamInArray() {
        $param = parent::getParamInArray();
        if (count($param) < 1) {
            return $param;
        }
        if (empty($this->aggregation)) {
            $this->resetLastError(-1, '参数aggregation不能为空。');
            return array();
        }
        if (!is_array($this->range)) {
            $this->resetLastError(-1, '参数range应该是一个整数数组。');
            return array();
        }
        $param['aggregation'] = $this->aggregation;
        $param['range']       = $this->range;
        return $param;
    }

    /// range参数。
    private $range;
    /// 聚合操作名
    private $aggregation;
}