<?php

/**
 * AbleCloud数据分析服务的过滤条件，如：temperature >= 38.5。
 */
class ACQEFilter {
/// @name 过滤条件中的操作符。
    //@{
    /// 相等
    public static $Equal              = 'eq';
    /// 不相等
    public static $NotEqual           = 'ne';
    /// 小于
    public static $LessThan           = 'lt';
    /// 小于或等于
    public static $LessThanOrEqual    = 'lte';
    /// 大于
    public static $GreaterThan        = 'gt';
    /// 大于或等于
    public static $GreaterThanOrEqual = 'gte';
    /// 包含，用于字符串模糊匹配。
    public static $Contain            = 'contains';
    /// 不包含，用于字符串模糊匹配。
    public static $NotContain         = 'not_contains';
    /// 在...中。此时用作判断的基准值应该为数组形式,如[2, 3, 4,5]等。
    public static $In                  = 'in';
    /// 值在某个范围内。此时用作判断的基准值应该为包含两个元素的数组，如[10, 20]或["2015-07-10","2015-07-11"]等。
    public static $Between             = 'between';
    //@}

    /**
     * 构造函数。
     * @param $propertyName string  是查询条件中的数据列的名字。
     * @param $operator     string  是查询条件中的操作符，ACQEFilter::$Equal，ACQEFilter::$NotEqual等。
     * @param $value        mixed   是查询条件的判断基准值，其类型取决于对应的数据列的类型以及操作符的要求。
     */
    function __construct($propertyName, $operator, $value) {
        $this->propertyName = $propertyName;
        $this->operator     = $operator;
        $this->value        = $value;
    }

    /**
     * 重置过滤条件。
     * @param $propertyName string  是查询条件中的数据列的名字。
     * @param $operator     string  是查询条件中的操作符，ACQEFilter::$Equal，ACQEFilter::$NotEqual等。
     * @param $value        mixed   是查询条件的判断基准值，其类型取决于对应的数据列的类型以及操作符的要求。
     * @return              ACQEFilter  返回本对象。
     */
    public function set($propertyName, $operator, $value) {
        $this->propertyName = $propertyName;
        $this->operator     = $operator;
        $this->value        = $value;
        return $this;
    }

    /**
     * 将对象转为AC-QueryEngine接受的参数格式。
     * @return array    以数组形式记录的参数。
     */
    public function toParamInArray() {
        return array(
            'property_name' => $this->propertyName,
            'operator' => $this->operator,
            'property_value' => $this->value
        );
    }

    /// 查询所依赖的数据列。
    private $propertyName;
    /// 查询的操作符。
    private $operator;
    /// 查询条件的参考值。
    private $value;
}