<?php
/**
 * AbleCloud数据分析服务的查询条件集合：ACQEFilter对象的集合。
 */
class ACQEPropertyFilters {
    /**
     * 设置集合中ACQEFilter对象之间的连接关系。缺省值为'AND'。
     * @param $isAnd    bool    为TRUE时表示集合中的ACQEFilter对象以AND关系连接。
     * @return          ACQEPropertyFilters 返回本集合对象。
     */
    public function setRelation($isAnd) {
        if ($isAnd)
            $this->relation = 'AND';
        else
            $this->relation = 'OR';
        return $this;
    }

    /**
     * 向集合中添加查询条件。
     * @param $filter   ACQEFilter          查询条件。
     * @return          ACQEPropertyFilters 返回本集合对象。
     */
    public function appendFilter($filter) {
        array_push($this->filters, $filter);
        return $this;
    }

    /**
     * 将对象转为AC-QueryEngine接受的参数格式。
     * @return array    以数组形式记录的参数。
     */
    public function toParamInArray() {
        $filters = array();
        foreach ($this->filters as $k => $f) {
            array_push($filters, $f->toParamInArray());
        }
        $param = array('property_filters' => $filters);
        if (count($filters) > 1) {
            $param['relation'] = $this->relation;
        }
        return $param;
    }

    private $relation = 'AND';
    private $filters  = array();
}