<?php

require_once(dirname(__FILE__) . '/ACService.php');

/**
 * AbleCloud短信服务。
 */
class ACSMSMgr extends ACService {
    /**
     * 构造函数。
     * @param $name		string		AbleCloud短信服务的名字。字符串。
     * @param $version	int			AbleCloud短信服务的主版本值。整数。
     * @param $context	ACContext	表示访问该远程服务所依赖的环境信息。
     */
    function __construct($name, $version, $context) {
        parent::__construct($name, $version, $context);
    }

    /**
     * 向用户发送短信。
     * @param $userList     array   用户ID列表。每次最多发送给50名用户。
     * @param $templateId   int     在AbleCloud平台注册的短信模板ID。
     * @param $content      string  短信内容：用于替换模板中的{数字}。若有多个替换内容，用英文逗号隔开即可。
     * @return              bool    发送短信成功时返回TRUE，否则返回FALSE。返回FALSE时可调用getLastError()方法获取错误信息。
     */
    public function sendSmsByUserList($userList, $templateId, $content) {
        if (!is_array($userList) || count($userList) > 50) {
            $this->resetLastError(-1, '$userList is not an array or has more than 50 elements.');
            return FALSE;
        }
        $request = new ACRequest($this->getName(), 'sendSmsMessageByUserList', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('userList' => $userList, 'template' => strval($templateId), 'content' => strval($content))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * 向用户发送短信。
     * @param $phone        string  用户的手机号。
     * @param $templateId   int     在AbleCloud平台注册的短信模板ID。
     * @param $content      string  发送短信成功时返回TRUE，否则返回FALSE。返回FALSE时可调用getLastError()方法获取错误信息。
     * @return              bool    发送短信成功时返回TRUE，否则返回FALSE。返回FALSE时可调用getLastError()方法获取错误信息。
     */
    public function sendSmsMessage($phone, $templateId, $content) {
        $request = new ACRequest($this->getName(), 'sendSmsMessage', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('phone' => $phone, 'template' => strval($templateId), 'content' => strval($content))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }

    /**
     * 向用户发送短信。
     * @param $phoneList    string  用户的手机号列表。每次最多发送给50名用户。
     * @param $templateId   int     在AbleCloud平台注册的短信模板ID。
     * @param $content      string  短信内容：用于替换模板中的{数字}。若有多个替换内容，用英文逗号隔开即可。
     * @return              bool    发送短信成功时返回TRUE，否则返回FALSE。返回FALSE时可调用getLastError()方法获取错误信息。
     */
    public function sendSmsMessageByPhoneList($phoneList, $templateId, $content) {
        if (!is_array($phoneList) || count($phoneList) > 50) {
            $this->resetLastError(-1, '$phoneList is not an array or has more than 50 elements.');
            return FALSE;
        }
        $request = new ACRequest($this->getName(),'sendSmsMessageByPhoneList', $this->getVersion());
        $request->setPayloadAsJSON(json_encode(array('phoneList' => $phoneList, 'template' => strval($templateId), 'content' => strval($content))));
        $response = ACHttpClient::doRequest($request, $this->getContext());
        if ($response->isAck()) {
            $this->resetLastError();
            return TRUE;
        } else {
            $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
            return FALSE;
        }
    }
}