<?php

require_once(dirname(__FILE__) . '/ACContext.php');
require_once(dirname(dirname(__FILE__)) . '/httpclient/ACHttpClient.php');

/**
 * AbleCloud服务。
 */
class ACService {
	/**
	 * 构造函数。
	 * @param $name		string		服务的名字。字符串。
	 * @param $version	int			服务的主版本值。整数。
	 * @param $context	ACContext	表示访问该远程服务所依赖的环境信息。
	 */
	function __construct($name, $version, $context) {
		$this->name = $name;
		$this->version = $version;
		$this->context = $context;
		$this->lastError = array('errCode' => 0, 'errMessage' => '');
	}

	/**
	 * 取服务的名字。
	 * @return string	返回服务的名字。
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * 取服务的主版本值。
	 * @return int	返回一个整数，表示服务的主版本值。
	 */
	public function getVersion() {
		return $this->version;
	}

	/**
	 * 取访问该服务所依赖的环境信息。
	 * @return ACContext	返回ACContext对象，表示环境信息。
	 */
	public function getContext() {
		return $this->context;
	}

	/**
	 * 取最近一次错误消息。
	 * @return array	返回一个包含错误码和消息的关联数组：['errCode': 0, 'errMessage': '']。errCode为0时表示没有错误发生。
	 */
	public function getLastError() {
		return $this->lastError;
	}

	/**
	 * 重置错误信息。
	 * @param $errCode		int		错误消息码。
	 * @param $errMessage	string	消息内容。
	 */
	protected function resetLastError($errCode = 0, $errMessage = '') {
		$this->lastError = array('errCode' => $errCode, 'errMessage' => $errMessage);
	}

	private $name;		// 服务的名字。
	private $version;	// 服务的主版本值。
	private $context;	// 访问远程服务所依赖的环境信息。
	private $lastError;	// 最后一次错误信息。
}