<?php

/**
 * AlbeCloud数据存储服务的数据集中数据列的定义。
 */
class ACStoreClassColumn {
	public $name;	/// 列的名字。字符串。
	public $type;	/// 列的数据类型。整数。1：整数类型；2：浮点数类型；3：布尔值；4：字符串；其它：未知类型。
	public $length;	/// 列的值的长度。仅字符串类型的列需要指定长度：[1, 1024]。默认为255。

	/**
	 * 构造函数。
	 * @param $name 列的名字。
	 * @param $type 列的数据类型，整数。1：整数类型；2：浮点数类型；3：布尔值；4：字符串；其它：未知类型。
	 * @param $length 列的值的长度。仅字符串类型的列需要指定长度：[1, 1024]。默认为255。
	 */
	function __construct($name, $type, $length = 255) {
		$this->name = $name;
		$this->type = $type;
		$length = intval($length);
		if ($length > 1024)
			$length = 1024;
		if ($length < 1)
			$length = 1;
		$this->length = $length;
	}

	/**
	 * 取本列的数据类型的名字。
	 * @return 返回本列的数据类型的名字。
	 */
	public function getTypeName() {
		switch ($this->type) {
			case 1:
				return '整数';
			case 2:
				return '浮点数';
			case 3:
				return '布尔值';
			case 4:
				return '字符串';
			default:
				return '未知';
		}
	}
}

/**
 * AbleCloud数据存储服务的数据集。
 */
class ACStoreClass {
	public $domain;				/// 数据集所属主域的名字。
	public $name;				/// 数据集的名字：字母、数字或下划线。
	public $columns;			/// 数据集的全部数据列：ACStoreClassColumn对象的数组。
	public $primaryKeys;		/// 数据集的主键：ACStoreClassColumn对象的数组。
	public $entityGroupKeys;	/// 数据集的分区键：ACStoreClassColumn对象的数组。如果该数组不为空数组，则表示使用分区策略；否则表示不使用分区策略。
	public $enableWatch;		/// 布尔值，是否启用数据监控功能。缺省取FALSE。

	/**
	 * 构造函数。
	 * @param $domain 数据集所属的主域的名字。
	 * @param $name 数据集的名字：字母、数字或下划线。
	 */
	function __construct($domain, $name) {
		$this->domain = $domain;
		$this->name = $name;
		$this->columns     = array();
		$this->primaryKeys = array();
		$this->entityGroupKeys = array();
		$this->enableWatch = FALSE;
	}

	/**
	 * 将本对象编码成JSON格式的字符串。
	 * @return 返回JSON格式的字符串。
	 */
	public function jsonEncode() {
		$columns = array();
		foreach ($this->columns as $key) {
			array_push($columns, array(
				'attributeName'   => $key->name,
				'attributeType'   => $key->type,
				'attributeLength' => $key->length
			));
		}
		$primaryKeys = array();
		foreach ($this->primaryKeys as $key) {
			array_push($primaryKeys, array(
				'attributeName'   => $key->name,
				'attributeType'   => $key->type,
				'attributeLength' => $key->length
			));
		}
		$entityGroupKeys = array();
		foreach ($this->entityGroupKeys as $key) {
			array_push($entityGroupKeys, array(
				'attributeName'   => $key->name,
				'attributeType'   => $key->type,
				'attributeLength' => $key->length
			));
		}

		$data = array(
			'domain'			=> $this->domain,
			'className'			=> $this->name,
			'columns'			=> $columns,
			'primaryKeys'		=> $primaryKeys,
			'entityGroupKeys'	=> $entityGroupKeys,
			'watchEnable'		=> $this->enableWatch
		);
		return json_encode($data);
	}
}