<?php

/**
 * AbleCloud存储服务的查询条件，如：time > 1436170756857177。
 */
class ACStoreFilter {
    /// @name 查询条件中的操作符。
    //@{
    /// 相等
    public static $Equal          = 1;
    /// 不相等
    public static $NotEqual       = 2;
    /// 大于
    public static $Greater        = 3;
    /// 大于或等于
    public static $GreaterOrEqual = 4;
    /// 小于
    public static $Less           = 5;
    /// 小于或等于
    public static $LessOrEqual    = 6;
    /// SQL: like。不区分大小写。需要显示指定通配符'%'。
    public static $Like           = 7;
    /// SQL: not like。不区分大小写。需要显示指定通配符'%'。
    public static $NotLike        = 8;
    /// SQL: binary like。区分大小写。需要显示指定通配符'%'。
    public static $BinaryLike     = 9;
    /// SQL: binary not like。区分大小写。需要显示指定通配符'%'。
    public static $BinaryNotLike  = 10;
    /// SQL: in
    public static $In             = 11;
    /// SQL: not in
    public static $NotIn          = 12;
    //@}

    /**
     * 构造函数。
     * @param $columnName 字符串，是查询条件中的数据列的名字。
     * @param $operator   整数，是查询条件中的操作符，如ACStoreFilter::$Equal，ACStoreFilter::$NotEqual等。
     * @param $value      整数、浮点数、字符串或布尔值，是查询条件中的目标值。
     */
    function __construct($columnName, $operator, $value) {
        $this->columnName = $columnName;
        $this->operator   = $operator;
        $this->value      = $value;
        $this->nextFilter = NULL;
        $this->andToPrevious = true;
    }

    /**
     * 将本对象以逻辑“与”的关系与另一个ACStoreFilter对象关联起来。
     * @param $filter ACStoreFilter对象，要关联的查询条件。
     * @return ACStoreFitler对象，是当前关联起来的查询条件的列表中处于末尾位置的ACStoreFilter对象。
     */
    public function andFilter($filter) {
        $tail = $this;
        while ($tail->nextFilter != NULL && $tail->nextFilter !== $this) {
            $tail = $tail->nextFilter;
        }
        if ($filter != NULL) {
            $filter->andToPrevious = TRUE;
            $tail->nextFilter = $filter;
            $tail = $filter;
        }
        return $tail;
    }

    /**
     * 将本对象以逻辑“或”的关系与另一个ACStoreFilter对象关联起来。
     * @param $filter ACStoreFilter对象，要关联的查询条件。
     * @return ACStoreFitler对象，是当前关联起来的查询条件的列表中处于末尾位置的ACStoreFilter对象。
     */
    public function orFilter($filter) {
        $tail = $this;
        while ($tail->nextFilter != NULL && $tail->nextFilter !== $this) {
            $tail = $tail->nextFilter;
        }
        if ($filter != NULL) {
            $filter->andToPrevious = FALSE;
            $tail->nextFilter = $filter;
            $tail = $filter;
        }
        return $tail;
    }
    
    /**
     * 生成本对象的一个拷贝：仅复制数据列名、操作符，以及目标值。
     * @return ACStoreFilter 是本对象的拷贝。
     */
    public function getCopy() {
    	return new ACStoreFilter($this->columnName, $this->operator, $this->value);
    }

	/// 查询所依赖的数据列。
    public $columnName;
    /// 查询的操作符。
    public $operator;
    /// 查询条件的参考值。
    public $value;
    // ACStoreFilter对象链表
    /// 所链接的后一个ACStoreFilter对象。缺省为NULL，表示没有下一个查询条件。
    public $nextFilter;
    /// 与前一个ACStoreFilter对象的链接关系：true-逻辑与；false-逻辑或。
    public $andToPrevious;
}
