<?php

require_once(dirname(__FILE__) . '/ACService.php');
require_once(dirname(__FILE__) . '/ACStoreScanner.php');

/**
 * AbleCloud存储服务查询结果集合的迭代器。
 */
class ACStoreIterator extends ACService {
    /**
     * 构造函数。
     * @param $name 数据存储服务的名字。
     * @param $version 数据存储服务的版本。
     * @param $context ACContext对象，表示访问该远程服务所依赖的环境信息。
     * @param $scanner ACStoreScanner对象，表示查询条件。
     */
    function __construct($name, $version, $context, $scanner) {
        parent::__construct($name, $version, $context);
        $this->scanner = $scanner;
        $this->partitionCount = 1;
        $this->currentPartition = 0;
    }

    /**
     * 取查询结果集合中的下一批数据记录。返回NULL时表示已遍历完整个数据集。
     * @details 实际上，当前第一次调用本方法就返回所有符合条件的记录，因此不用多次调用来检查是否已取到了所有数据。
     * @return - 返回一个数组。数组中的每个元素是一个关联数组，表示一条数据记录。
     *  - 返回NULL表示已遍历完整个集合。
     *  - 返回FALSE时，表示有错误发生。此时可调用getLastError()方法获取错误消息。
     */
    public function next() {
        return $this->nextInPartition();
    }

    private function nextInPartition() {
        if ($this->currentPartition < $this->partitionCount) {
            $this->currentPartition += 1;
            $request = new ACRequest($this->getName(), 'scan', $this->getVersion());
            $scanParam = $this->scanner->toScanParam();
            $request->setPayloadAsJSON(json_encode(array('className' => $this->scanner->getClassName(), 'scanParam' => $scanParam)));
            $response = ACHttpClient::doRequest($request, $this->getContext());
            if ($response->isAck()) {
                $this->resetLastError();
                $payload = json_decode($response->getResponse(), true);
                return $payload['objects'];
            } else {
                $this->resetLastError($response->getErrorCode(), $response->getErrorMessage());
                return FALSE;
            }
        } else {
            if ($this->partitionCount == 0)
                return FALSE;
            else
                return NULL;
        }
    }

    private $scanner;               /// ACStoreScanner对象，表示查询条件。
    private $partitionCount;        /// 分片总数
    private $currentPartition;      /// 当前处理的分片的索引（从0开始）。
}