<?php

/**
 * 用户信息。
 */
class ACUser {
	/**
	 * 构造函数。
	 * @param $id		string	用户的ID。
	 * @param $token	string	用户的Token。
	 * @param $name		string	用户的显示名。字符串。
	 * @param $refreshToken				string	用于更新用户Token的Token。
	 * @param $tokenExpiration			string	用户Token的过期时间（UTC）：YYYY-MM-DD hh:mm:ss。空字符串表示不过期。
	 * @param $refreshTokenExpiration	string	用户的$refreshToken的过期时间（UTC）：YYYY-MM-DD hh:mm:ss。空字符串表示不过期。
	 * @param $email	string	用户注册的邮箱地址。
	 * @param $phone	string	用户注册的电话号码。
	 */
	function __construct($id, $token, $name = '', $refreshToken = '', $tokenExpiration = '', $refreshTokenExpiration = '', $email = '', $phone = '') {
		$this->id	 = $id;
		$this->token = $token;
		$this->name  = $name;
		$this->refreshToken			  = $refreshToken;
		$this->tokenExpiration		  = $tokenExpiration;
		$this->refreshTokenExpiration = $refreshTokenExpiration;
		$this->email = $email;
		$this->phone = $phone;
	}

	/**
	 * 取用户的ID。
	 * @return	string	返回用户的ID。整数。
	 */
	public function getId() {
		return $this->id;
	}

	/**
	 * 取用户的名字。
	 * @return	string	返回用户的名字。
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * 取用户的Token。
	 * @return	string	返回用户的Token。字符串。
	 */
	public function getToken() {
		return $this->token;
	}

	/**
	 * 取Token的过期时间（UTC）：YYYY-MM-DD hh:mm:ss。
	 * @return string	Token的过期时间。空字符串表示不过期。
	 */
	public function getTokenExpiration() {
		return $this->tokenExpiration;
	}

	/**
	 * 设置用户Token。
	 * @param $token			string	用户的Token。
	 * @param $tokenExpiration	string	用户的Token的过期时间（UTC）：YYYY-MM-DD hh:mm:ss。空字符串表示不过期。
	 */
	public function setToken($token, $tokenExpiration) {
		$this->token = $token;
		$this->tokenExpiration = $tokenExpiration;
	}

	/**
	 * 取用于更新用户Token的Token。
	 * @return string	用于更新用户Token的Token。
	 */
	public function getRefreshToken() {
		return $this->refreshToken;
	}

	/**
	 * 取RefreshToken的过期时间（UTC）：YYYY-MM-DD hh:mm:ss。
	 * @return string	RefreshToken的过期时间。空字符串表示不过期。
	 */
	public function getRefreshTokenExpiration() {
		return $this->refreshTokenExpiration;
	}

	/**
	 * 设置用于更新Token的Token。
	 * @param $refreshToken				string	用于更新Token的Token。
	 * @param $refreshTokenExpiration	string	RefreshToken的过期时间（UTC）：YYYY-MM-DD hh:mm:ss。空字符串表示不过期。
	 */
	public function setRefreshToken($refreshToken, $refreshTokenExpiration) {
		$this->refreshToken = $refreshToken;
		$this->refreshTokenExpiration = $refreshTokenExpiration;
	}

	/**
	 * 取用户的注册邮箱地址。
	 * @return string	用户注册邮箱地址。
	 */
	public function getEmail() {
		return $this->email;
	}

	/**
	 * 取用户注册的电话。
	 * @return string	用户注册的电话。
	 */
	public function getPhone() {
		return $this->phone;
	}

	private $id;
	private $token;
	private $name;
	private $email;
	private $phone;
	private $refreshToken;
	private $tokenExpiration;
	private $refreshTokenExpiration;
}