<?php

/**
 * 天气的数据结构。
 */
class ACWeather {
    /**
     * 字符串，是天气状态对应的时间。
     * 对应最新天气的时间格式为"yyyy-MM-dd HH:mm:ss"。
     * 对应最近几天的天气的时间格式为"yyyy-MM-dd"。
     * 对应最近几小时的天气的时间格式为"yyyy-MM-dd HH"。
     */
    public $timestamp;
    /// 浮点数，温度。
    public $temperature;
    /// 浮点数，最低温度。
    public $minTemperature;
    /// 浮点数，最高温度。
    public $maxTemperature;
    /// 整数，湿度。
    public $humidity;
    /// 整数，最低湿度。
    public $minHumidity;
    /// 整数，最高湿度。
    public $maxHumidity;

    /**
     * 从关联数组对象构造ACWeather对象。
     * @param $obj  array       保存了天气信息的对象。
     * @return      ACWeather   ACWeather对象或者NULL。
     */
    public static function fromObject($obj) {
        if (!is_array($obj))
            return NULL;
        $w = new ACWeather();
        if (array_key_exists('timestamp', $obj)) {
            $w->timestamp = $obj['timestamp'];
        }
        if (array_key_exists('temperature', $obj)) {
            $w->temperature = floatval($obj['temperature']);
        }
        if (array_key_exists('minTemperature', $obj)) {
            $w->minTemperature = intval($obj['minTemperature']);
        }
        if (array_key_exists('maxTemperature', $obj)) {
            $w->maxTemperature = intval($obj['maxTemperature']);
        }
        if (array_key_exists('humidity', $obj)) {
            $w->humidity = floatval($obj['humidity']);
        }
        if (array_key_exists('minHumidity', $obj)) {
            $w->minHumidity = intval($obj['minHumidity']);
        }
        if (array_key_exists('maxHumidity', $obj)) {
            $w->maxHumidity = intval($obj['maxHumidity']);
        }
        return $w;
    }
}